@@ -61,8 +61,7 @@ class RichJupyterWidget(RichIPythonWidget):
         # Do we support jpg ?
         # it seems that sometime jpg support is a plugin of QT, so try to assume
         # it is not always supported.
-        _supported_format = [bytes(f) for f in QtGui.QImageReader.supportedImageFormats()]
-        self._jpg_supported = b'jpeg' in _supported_format
+        self._jpg_supported = 'jpeg' in QtGui.QImageReader.supportedImageFormats()
 
 
     #---------------------------------------------------------------------------
@@ -214,11 +213,18 @@ class RichJupyterWidget(RichIPythonWidget):
     def _append_latex(self, latex, before_prompt=False, metadata=None):
         """ Append latex data to the widget."""
         png = None
+
         if self._is_latex_math(latex):
             png = latex_to_png(latex, wrap=False, backend='dvipng')
+
+        # Matplotlib only supports strings enclosed in dollar signs
         if png is None and latex.startswith('$') and latex.endswith('$'):
-            # matplotlib only supports strings enclosed in dollar signs
-            png = latex_to_png(latex, wrap=False, backend='matplotlib')
+            # To avoid long and ugly errors, like the one reported in
+            # spyder-ide/spyder#7619
+            try:
+                png = latex_to_png(latex, wrap=False, backend='matplotlib')
+            except Exception:
+                pass
 
         if png:
             self._append_png(png, before_prompt, metadata)
@@ -358,11 +364,13 @@ class RichJupyterWidget(RichIPythonWidget):
             image = QtGui.QImage()
             image.loadFromData(img, fmt.upper())
             if width and height:
-                image = image.scaled(width, height, transformMode=QtCore.Qt.SmoothTransformation)
+                image = image.scaled(width, height,
+                                     QtCore.Qt.IgnoreAspectRatio,
+                                     QtCore.Qt.SmoothTransformation)
             elif width and not height:
-                image = image.scaledToWidth(width, transformMode=QtCore.Qt.SmoothTransformation)
+                image = image.scaledToWidth(width, QtCore.Qt.SmoothTransformation)
             elif height and not width:
-                image = image.scaledToHeight(height, transformMode=QtCore.Qt.SmoothTransformation)
+                image = image.scaledToHeight(height, QtCore.Qt.SmoothTransformation)
         except ValueError:
             self._insert_plain_text(cursor, 'Received invalid %s data.'%fmt)
         else:
